@@ -11,13 +11,13 @@ HTML::Widget::Plugin::Checkbox - it's either [ ] or [x]
 
 =head1 VERSION
 
-version 0.055
+version 0.057
 
- $Id: Checkbox.pm 28249 2007-02-28 20:48:46Z rjbs $
+ $Id: Checkbox.pm 29262 2007-05-01 17:18:29Z rjbs $
 
 =cut
 
-our $VERSION = '0.055';
+our $VERSION = '0.057';
 
 =head1 DESCRIPTION
 
@@ -51,20 +51,24 @@ are valid arguments:
 This is the widget's initial state.  If true, the checkbox is checked.
 Otherwise, it is not.
 
+=item value
+
+This is the value for the checkbox, not to be confused with whether or not it
+is checked.
+
 =back
 
 =cut
 
 sub _attribute_args { qw(checked value) }
-sub _boolean_args   { qw(checked value) }
+sub _boolean_args   { qw(checked) }
 
 sub checkbox {
   my ($self, $factory, $arg) = @_;
 
-  my $value = delete $arg->{attr}{value};
-  $arg->{attr}{checked} ||= $value;
   $arg->{attr}{type} = 'checkbox';
-  $arg->{attr}{name} ||= $arg->{attr}{id};
+
+  $arg->{attr}{name} = $arg->{attr}{id} if not defined $arg->{attr}{name};
 
   my $widget = HTML::Element->new('input');
 
@@ -78,8 +82,8 @@ Ricardo SIGNES <C<rjbs @ cpan.org>>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005, Ricardo SIGNES.  This is free software, released under the
-same terms as perl itself.
+Copyright (C) 2005-2007, Ricardo SIGNES.  This is free software, released under
+the same terms as perl itself.
 
 =cut
 
